@@ -1,10 +1,225 @@
+use strict;
+use warnings;
 package Date::Tiny;
+# ABSTRACT: A date object, with as little code as possible
+
+our $VERSION = '1.07';
+
+use overload 'bool' => sub () { 1 };
+use overload '""'   => 'as_string';
+use overload 'eq'   => sub { "$_[0]" eq "$_[1]" };
+use overload 'ne'   => sub { "$_[0]" ne "$_[1]" };
+
+
+
+
+
+#####################################################################
+# Constructor and Accessors
+
+#pod =pod
+#pod
+#pod =method new
+#pod
+#pod   my $date = Date::Tiny->new(
+#pod       year  => 2006,
+#pod       month => 12,
+#pod       day   => 31,
+#pod       );
+#pod
+#pod The C<new> constructor creates a new B<Date::Tiny> object.
+#pod
+#pod It takes three named parameters. C<day> should be the day of the month (1-31),
+#pod C<month> should be the month of the year (1-12), C<year> as a 4 digit year.
+#pod
+#pod These are the only parameters accepted.
+#pod
+#pod Returns a new B<Date::Tiny> object.
+#pod
+#pod =cut
+
+sub new {
+	my $class = shift;
+	bless { @_ }, $class;
+}
+
+#pod =pod
+#pod
+#pod =method now
+#pod
+#pod   my $current_date = Date::Tiny->now;
+#pod
+#pod The C<now> method creates a new date object for the current date.
+#pod
+#pod The date created will be based on localtime, despite the fact that
+#pod the date is created in the floating time zone.
+#pod
+#pod Returns a new B<Date::Tiny> object.
+#pod
+#pod =cut
+
+sub now {
+	my @t = localtime time;
+	shift->new(
+		year  => $t[5] + 1900,
+		month => $t[4] + 1,
+		day   => $t[3],
+	);
+}
+
+#pod =pod
+#pod
+#pod =method year
+#pod
+#pod The C<year> accessor returns the 4-digit year for the date.
+#pod
+#pod =cut
+
+sub year {
+	$_[0]->{year};
+}
+
+#pod =pod
+#pod
+#pod =method month
+#pod
+#pod The C<month> accessor returns the 1-12 month of the year for the date.
+#pod
+#pod =cut
+
+sub month {
+	$_[0]->{month};
+}
+
+#pod =pod
+#pod
+#pod =method day
+#pod
+#pod The C<day> accessor returns the 1-31 day of the month for the date.
+#pod
+#pod =cut
+
+sub day {
+	$_[0]->{day};
+}
+
+#pod =pod
+#pod
+#pod =method ymd
+#pod
+#pod The C<ymd> method returns the most common and accurate stringified date
+#pod format, which returns in the form "2006-04-12".
+#pod
+#pod =cut
+
+sub ymd {
+	sprintf( "%04u-%02u-%02u",
+		$_[0]->year,
+		$_[0]->month,
+		$_[0]->day,
+	);
+}
+
+
+
+
+
+#####################################################################
+# Type Conversion
+
+#pod =pod
+#pod
+#pod =method as_string
+#pod
+#pod The C<as_string> method converts the date to the default string, which
+#pod at present is the same as that returned by the C<ymd> method above.
+#pod
+#pod This string matches the ISO 8601 standard for the encoding of a date as
+#pod a string.
+#pod
+#pod =cut
+
+sub as_string {
+	$_[0]->ymd;
+}
+
+#pod =pod
+#pod
+#pod =method from_string
+#pod
+#pod The C<from_string> method creates a new B<Date::Tiny> object from a string.
+#pod
+#pod The string is expected to be a "yyyy-mm-dd" ISO 8601 time string.
+#pod
+#pod   my $almost_christmas = Date::Tiny->from_string( '2006-12-23' );
+#pod
+#pod Returns a new B<Date::Tiny> object, or throws an exception on error.
+#pod
+#pod =cut
+
+sub from_string {
+	my $string = $_[1];
+	unless ( defined $string and ! ref $string ) {
+		require Carp;
+		Carp::croak("Did not provide a string to from_string");
+	}
+	unless ( $string =~ /^(\d\d\d\d)-(\d\d)-(\d\d)$/ ) {
+		require Carp;
+		Carp::croak("Invalid time format (does not match ISO 8601 yyyy-mm-dd)");
+	}
+	$_[0]->new(
+		year  => $1 + 0,
+		month => $2 + 0,
+		day   => $3 + 0,
+	);
+}
+
+#pod =pod
+#pod
+#pod =method DateTime
+#pod
+#pod The C<DateTime> method is used to create a L<DateTime> object
+#pod that is equivalent to the B<Date::Tiny> object, for use in
+#pod conversions and calculations.
+#pod
+#pod As mentioned earlier, the object will be set to the 'C' locate,
+#pod and the 'floating' time zone.
+#pod
+#pod If installed, the L<DateTime> module will be loaded automatically.
+#pod
+#pod Returns a L<DateTime> object, or throws an exception if L<DateTime>
+#pod is not installed on the current host.
+#pod
+#pod =cut
+
+sub DateTime {
+	require DateTime;
+	my $self = shift;
+	DateTime->new(
+		day       => $self->day,
+		month     => $self->month,
+		year      => $self->year,
+		locale    => 'C',
+		time_zone => 'floating',
+		@_,
+	);
+}
+
+1;
+
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Date::Tiny - A date object with as little code as possible
+Date::Tiny - A date object, with as little code as possible
+
+=head1 VERSION
+
+version 1.07
 
 =head1 SYNOPSIS
 
@@ -75,7 +290,7 @@ the usefulness greatly.
 
 To make up for this, B<if> you have L<DateTime> installed, any
 B<Date::Tiny> module can be inflated into the equivalent L<DateTime>
-as needing, loading L<DateTime> on the fly if necesary.
+as needing, loading L<DateTime> on the fly if necessary.
 
 For the purposes of date/time logic, all B<Date::Tiny> objects exist
 in the "C" locale, and the "floating" time zone (although obviously in a
@@ -88,32 +303,13 @@ override this).
 In addition, the implementation is strictly correct and is intended to
 be very easily to sub-class for specific purposes of your own.
 
-=head1 METHODS
+=head1 USAGE
 
 In general, the intent is that the API be as close as possible to the
 API for L<DateTime>. Except, of course, that this module implements
 less of it.
 
-=cut
-
-use strict;
-BEGIN {
-	require 5.004;
-	$Date::Tiny::VERSION = '1.04';
-}
-use overload 'bool' => sub () { 1 };
-use overload '""'   => 'as_string';
-use overload 'eq'   => sub { "$_[0]" eq "$_[1]" };
-use overload 'ne'   => sub { "$_[0]" ne "$_[1]" };
-
-
-
-
-
-#####################################################################
-# Constructor and Accessors
-
-=pod
+=head1 METHODS
 
 =head2 new
 
@@ -125,22 +321,13 @@ use overload 'ne'   => sub { "$_[0]" ne "$_[1]" };
 
 The C<new> constructor creates a new B<Date::Tiny> object.
 
-It takes three named params. C<day> should be the day of the month (1-31),
+It takes three named parameters. C<day> should be the day of the month (1-31),
 C<month> should be the month of the year (1-12), C<year> as a 4 digit year.
 
-These are the only params accepted.
+These are the only parameters accepted.
 
 Returns a new B<Date::Tiny> object.
 
-=cut
-
-sub new {
-	my $class = shift;
-	bless { @_ }, $class;
-}
-
-=pod
-
 =head2 now
 
   my $current_date = Date::Tiny->now;
@@ -152,79 +339,23 @@ the date is created in the floating time zone.
 
 Returns a new B<Date::Tiny> object.
 
-=cut
-
-sub now {
-	my @t = localtime time;
-	shift->new(
-		year  => $t[5] + 1900,
-		month => $t[4] + 1,
-		day   => $t[3],
-	);
-}
-
-=pod
-
 =head2 year
 
 The C<year> accessor returns the 4-digit year for the date.
 
-=cut
-
-sub year {
-	$_[0]->{year};
-}
-
-=pod
-
 =head2 month
 
 The C<month> accessor returns the 1-12 month of the year for the date.
 
-=cut
-
-sub month {
-	$_[0]->{month};
-}
-
-=pod
-
 =head2 day
 
 The C<day> accessor returns the 1-31 day of the month for the date.
 
-=cut
-
-sub day {
-	$_[0]->{day};
-}
-
-=pod
-
 =head2 ymd
 
 The C<ymd> method returns the most common and accurate stringified date
 format, which returns in the form "2006-04-12".
 
-=cut
-
-sub ymd {
-	sprintf( "%04u-%02u-%02u",
-		$_[0]->year,
-		$_[0]->month,
-		$_[0]->day,
-	);
-}
-
-
-
-
-
-#####################################################################
-# Type Conversion
-
-=pod
-
 =head2 as_string
 
 The C<as_string> method converts the date to the default string, which
@@ -233,14 +364,6 @@ at present is the same as that returned by the C<ymd> method above.
 This string matches the ISO 8601 standard for the encoding of a date as
 a string.
 
-=cut
-
-sub as_string {
-	$_[0]->ymd;
-}
-
-=pod
-
 =head2 from_string
 
 The C<from_string> method creates a new B<Date::Tiny> object from a string.
@@ -251,30 +374,11 @@ The string is expected to be a "yyyy-mm-dd" ISO 8601 time string.
 
 Returns a new B<Date::Tiny> object, or throws an exception on error.
 
-=cut
-
-sub from_string {
-	my $string = $_[1];
-	unless ( defined $string and ! ref $string ) {
-		Carp::croak("Did not provide a string to from_string");
-	}
-	unless ( $string =~ /^(\d\d\d\d)-(\d\d)-(\d\d)$/ ) {
-		Carp::croak("Invalid time format (does not match ISO 8601 yyyy-mm-dd)");
-	}
-	$_[0]->new(
-		year  => $1 + 0,
-		month => $2 + 0,
-		day   => $3 + 0,
-	);
-}
-
-=pod
-
 =head2 DateTime
 
 The C<DateTime> method is used to create a L<DateTime> object
 that is equivalent to the B<Date::Tiny> object, for use in
-comversions and caluculations.
+conversions and calculations.
 
 As mentioned earlier, the object will be set to the 'C' locate,
 and the 'floating' time zone.
@@ -284,49 +388,53 @@ If installed, the L<DateTime> module will be loaded automatically.
 Returns a L<DateTime> object, or throws an exception if L<DateTime>
 is not installed on the current host.
 
-=cut
+=head1 HISTORY
 
-sub DateTime {
-	require DateTime;
-	my $self = shift;
-	DateTime->new(
-		day       => $self->day,
-		month     => $self->month,
-		year      => $self->year,
-		locale    => 'C',
-		time_zone => 'floating',
-		@_,
-	);
-}
-
-1;
-
-=pod
-
-=head1 SUPPORT
-
-Bugs should be reported via the CPAN bug tracker at
-
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Date-Tiny>
-
-For other issues, or commercial enhancement or support, contact the author.
-
-=head1 AUTHOR
-
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+This module was written by Adam Kennedy in 2006.  In 2016, David Golden
+adopted it as a caretaker maintainer.
 
 =head1 SEE ALSO
 
 L<DateTime>, L<DateTime::Tiny>, L<Time::Tiny>, L<Config::Tiny>, L<ali.as>
 
-=head1 COPYRIGHT
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
-Copyright 2006 - 2009 Adam Kennedy.
+=head1 SUPPORT
 
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
+=head2 Bugs / Feature Requests
 
-The full text of the license can be found in the
-LICENSE file included with this module.
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/dagolden/Date-Tiny/issues>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software.  The code repository is available for
+public review and contribution under the terms of the license.
+
+L<https://github.com/dagolden/Date-Tiny>
+
+  git clone https://github.com/dagolden/Date-Tiny.git
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Adam Kennedy <adamk@cpan.org>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2006 by Adam Kennedy.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
